#include <cassert>
#include <cmath>
#include <cstdio>                                           // for rename()
#include <cstdlib>                                          // for system()
#include <ctime>                                        // in prn_results()
#include <fstream>
#include <iomanip>
#include <iostream>
#include <libgen.h>                                       // for basename()
#include <limits>                     // for xmin, xmax, gammq() and gser()
#include <sstream>
#include <vector>
#include <getopt.h>

using namespace std;

typedef  const int      cint;
typedef  unsigned       uns;
typedef  double         dbl;
typedef  const double   cdbl;
typedef  const string   cstring;
typedef  istringstream  isstream;
typedef  ostringstream  osstream;
typedef  vector<dbl>    dvec;

enum no_yes {no, yes};

struct result {
    uns npts;                                      // number of data points
    uns ssize;                          // size of sigma vector in datafile
    int sigmas;                              // is sigmas option specified?
    dbl a;                                                         // slope
    dbl siga;                                             // error in slope
    dbl b;                                                     // intercept
    dbl sigb;                                         // error in intercept
    dbl corr;                                    // correlation coefficient
    dbl conf;                                    // confidence level in pct
    dbl chisq;                                                // chi-square
    dbl alpha;                        // probability of a larger chi-square
    dvec x;                                    // x-vector needed for graph
    string datafile;                                       // datafile name
    string td;                                          // time/date string
};

struct opts {
    int sigmas;              // yes if independent sigmas supplied in col 3
};

// prototypes
//
void trimspace(string&);
void gopen(ifstream& ifs, cstring fname);
void gopen(ofstream& ofs, cstring fname);
void err(cstring);
void warn(cstring);
void err(cstring, cstring);
void err(cstring, cstring, cstring);
void err(cstring, int);
void err(cstring, int, cstring);
void get_data(ifstream& ifs, dvec& x, dvec& y, dvec& s, opts o, result& r);
void get_opts(int, char**, opts&);
void gsystem(cstring cmd);
void calculate(dvec& x, dvec& y, dvec& s, opts&, result&);
void prn_usage(char**);
void prn_info(char**);
void prn_results(result&, opts&);
void mk_graph(result&, opts);
dbl  factln(cint);
dbl  gammln(cdbl);
dbl  gammq(cdbl, cdbl);
dbl gser(cdbl, cdbl);
dbl gcf(cdbl, cdbl);
cdbl pi();
no_yes query_user();
string get_string(cstring, cstring, uns);
dbl  norm(uns);
dbl  stud(dbl, uns);
dbl  student(uns, cdbl);

void  error_exit_cannot_get_here(const string fname, cint line_no);
void  gstrftime(string& s, cstring format, const struct tm* tm);
