//
// gets x values (col 1) and y values (col 2) and
// (optional) sigmas (col 3).
// if col 3, there must be one for each data point value.
//

#include "fitline.h"

extern int optind;

void get_data(ifstream& ifs, dvec& x, dvec& y, dvec& s, opts o, result& r)
{
  uns k;
  uns n;
  dbl z;                                    // will contain x or y or sigma
  string line;
  isstream iss;

  for (k = 1; getline(ifs, line); ++k) {
    trimspace(line);
    n = 0;
    iss.clear();                                      // clear state of iss
    iss.str(line);                                   // put the line in iss
    while (iss >> z) {               // while a double (or int) is detected
      ++n;                                // increment over numbers in line
      if (n==1) {
        x.push_back(z);                     // grow the x (x-values) vector
      }
      else if (n==2) {
        y.push_back(z);                     // grow the y (y-values) vector
      }
      else if (n==3) {
        s.push_back(z);            // grow the (optional) s (sigmas) vector
      }
      else {                                                       // n > 3
        err("too many entries in datafile at line no. ", k);
      }
    }
    if ((s.size() != 0) && (s.size() != x.size())) {
      err("error in datafile near line no. ", k);
    }
  }
  r.ssize = s.size();                // save for later use in prn_results()

  if (!s.size() && o.sigmas)
    err("  You've specified the \"--sigmas\" option, but\n",
    "     I don't see any sigmas in your datafile!");

  if (!s.size()) {                    // if no sigmas, make each s[k] = 1.0
    for (k=0;k<x.size();k++)
      s.push_back(1.0);
  }
}
