//
// prints a help message on the screen
//
#include "fitline.h"
#include "config.h"           // for bug report address & WINCMD

void prn_info(char** argv)
{
  string pgname = basename(argv[0]);                 // chops long pathname

  if (pgname.rfind(".exe") != string::npos) {
    pgname.replace(pgname.find(".exe"),4,"");
  }

  #ifdef WINCMD // windows' cmd.exe does not honor bold type
  cout <<
    "\n " << pgname << ", when given a single"
    " argument datafile (the name of your data file),\n"
    " will attempt a least-squares fit of a straight line to the points contained\n"
    " in your datafile.  Such a straight line is assumed to be of the form\n"
    " y = a*x + b, with a slope a and a y-axis intercept"
    " b.  The program estimates\n"
    " values of the slope and intercept, complete with uncertainties.\n\n"

    " The datafile must have either two or three columns of numbers, separated by\n"
    " spaces or tabs.  The first column must contain the x values and the second\n"
    " column the associated y values.  The optional third column (if it exists),\n"
    " must contain the associated uncertainties (sigmas) of the y values, which\n"
    " will be used by the program to estimate the weight of each data point.\n"
    " These values may be independent estimates of the uncertainties (standard\n"
    " errors) of the y values, obtained, for example, by averaging, for each\n"
    " x value, a number of y values to obtain a standard error of the mean (at the\n"
    " 68.27 percent confidence level) for that set of y values.  Alternatively, the\n"
    " third column may contain relative estimates of the uncertainties in the\n"
    " y values.  Such relative uncertainties would be appropriate when independent\n"
    " estimates are not available, but when it is desired to assign unequal weights\n"
    " to each data point.  If independently obtained uncertainties in the y values\n"
    " are supplied, the --sigmas option (see below) should be invoked.  If the\n"
    " third column is missing, each point will be weighted equally.\n\n"

    " The datafile may contain comments or other blocks of text.  Such text blocks\n"
    " will be ignored by the program, as will any blank lines.  There is no need to\n"
    " precede such lines by \'sharp\' (#) characters.\n\n"

    " If independent estimates of the uncertainties are supplied and the --sigmas\n"
    " option is invoked, the program will also calculate and display a value of\n"
    " chi-square, which provides an indication for how well your data points are\n"
    " fit by the straight line.\n\n"

    " The program will ask if you want to create a graph.  If you say \"yes\" (or any\n"
    " word that begins with \"y\" or \"Y\") or just hit the \"Enter\" key, the program\n"
    " will create a python script that can be read by python, and eventually issue\n"
    " the command to display the graph.  This requires that python, numpy and\n"
    " matplotlib be installed on your machine.\n\n"

    " The program will ask if you would like to add a title, and/or labels for the\n"
    " x and y axes.  If you don't want a title or label, just hit the return key.\n"
    " A \"time/date\" string may be inserted into the title or either of the labels by\n"
    " typing td, preceded by a space.  For example, a title could be written as\n\n"

    "     These data were plotted at td.\n"
    "  This would produce a title like\n"
    "     These data were plotted at 12:55 PM on Nov 25, 2014.\n\n"

    " Then, after the version numbers of the three required packages are printed on\n"
    " your terminal, your graph should appear, from which its image may be saved as\n"
    " either a .png image, or a .pdf file, simply by clicking on the \"Save the\n"
    " figure\" icon on the graph display.\n\n"

    " After you exit the graph, the program will ask if you want to remove\n"
    " datafile.tmp.  Say \"no\" if you might still want to edit the python script,\n"
    " since that .tmp file will be read by the script, and must be present for the\n"
    " python script to run.  You will need to edit the script (called datafile.py)\n"
    " if you want to add extra text strings to the graph, or modify the title or\n"
    " axis labels.  Such editing may be done after the program completes, and the\n"
    " command python datafile.py will re-display the graph.  Suggestions for how to\n"
    " add text strings are in the datafile.py file.\n\n"

    " If you want to save a copy of your results, which by default will be printed\n"
    " on your monitor screen, simply redirect the output to a file, e.g., like\n"
    " fitline --sigmas testfiles/radio_7pts > outfile\n"
    " Then the command cat outfile will display the outfile.\n\n"

    " Trouble or bug reports?  Send an email to Peter Scott <" << PACKAGE_BUGREPORT << ">.\n\n"

    " \t\t-------------------------------------\n";

  prn_usage(argv);

  #else
  cout <<
    "\n \033[1m" << pgname << "\033[0m, when given a single"
    " argument \033[1mdatafile\033[0m (the name of your data file),\n"
    " will attempt a least-squares fit of a straight line to the points contained\n"
    " in your datafile.  Such a straight line is assumed to be of the form\n"
    " \033[1my = a*x + b\033[0m, with a slope \033[1ma\033[0m and a y-axis intercept"
    " \033[1mb\033[0m.  The program estimates\n"
    " values of the slope and intercept, complete with uncertainties.\n\n"

    " The \033[1mdatafile\033[0m must have either two or three columns of numbers, separated by\n"
    " spaces or tabs.  The first column must contain the \033[1mx\033[0m values and the second\n"
    " column the associated \033[1my\033[0m values.  The optional third column (if it exists),\n"
    " must contain the associated uncertainties (\033[1msigmas\033[0m) of the \033[1my\033[0m values, which\n"
    " will be used by the program to estimate the weight of each data point.\n"
    " These values may be \033[1mindependent\033[0m estimates of the uncertainties (standard\n"
    " errors) of the \033[1my\033[0m values, obtained, for example, by averaging, for each\n"
    " \033[1mx\033[0m value, a number of \033[1my\033[0m values to obtain a standard error of the mean (at the\n"
    " 68.27 percent confidence level) for that set of \033[1my\033[0m values.  Alternatively, the\n"
    " third column may contain \033[1mrelative\033[0m estimates of the uncertainties in the\n"
    " \033[1my\033[0m values.  Such relative uncertainties would be appropriate when independent\n"
    " estimates are not available, but when it is desired to assign unequal weights\n"
    " to each data point.  If independently obtained uncertainties in the \033[1my\033[0m values\n"
    " are supplied, the \033[1m--sigmas\033[0m option (see below) should be invoked.  If the\n"
    " third column is missing, each point will be weighted equally.\n\n"

    " The \033[1mdatafile\033[0m may contain comments or other blocks of text.  Such text blocks\n"
    " will be ignored by the program, as will any blank lines.  There is no need to\n"
    " precede such lines by \'sharp\' (#) characters.\n\n"

    " If independent estimates of the uncertainties are supplied and the \033[1m--sigmas\033[0m\n"
    " option is invoked, the program will also calculate and display a value of\n"
    " \033[1mchi-square\033[0m, which provides an indication for how well your data points are\n"
    " fit by the straight line.\n\n"

    " The program will ask if you want to create a graph.  If you say \"\033[1myes\033[0m\" (or any\n"
    " word that begins with \"\033[1my\033[0m\" or \"\033[1mY\033[0m\") or just hit the \"\033[1mEnter\033[0m\" key, the program\n"
    " will create a python script that can be read by \033[1mpython\033[0m, and eventually issue\n"
    " the command to display the graph.  This requires that \033[1mpython\033[0m, \033[1mnumpy\033[0m and\n"
    " \033[1mmatplotlib\033[0m be installed on your machine.\n\n"

    " The program will ask if you would like to add a title, and/or labels for the\n"
    " x and y axes.  If you don't want a title or label, just hit the return key.\n"
    " A \"time/date\" string may be inserted into the title or either of the labels by\n"
    " typing \033[1mtd\033[0m, preceded by a space.  For example, a title could be written as\n\n"

    "     \033[1mThese data were plotted at td.\033[0m\n"
    "  This would produce a title like\n"
    "     \033[1mThese data were plotted at 12:55 PM on Nov 25, 2014.\033[0m\n\n"

    " Then, after the version numbers of the three required packages are printed on\n"
    " your terminal, your graph should appear, from which its image may be saved as\n"
    " either a \033[1m.png\033[0m image, or a \033[1m.pdf\033[0m file, simply by clicking on the \"Save the\n"
    " figure\" icon on the graph display.\n\n"

    " After you exit the graph, the program will ask if you want to remove\n"
    " \033[1mdatafile.tmp\033[0m.  Say \"no\" if you might still want to edit the python script,\n"
    " since that \033[1m.tmp\033[0m file will be read by the script, and must be present for the\n"
    " python script to run.  You will need to edit the script (called \033[1mdatafile.py\033[0m)\n"
    " if you want to add extra text strings to the graph, or modify the title or\n"
    " axis labels.  Such editing may be done after the program completes, and the\n"
    " command \033[1mpython datafile.py\033[0m will re-display the graph.  Suggestions for how to\n"
    " add text strings are in the \033[1mdatafile.py\033[0m file.\n\n"

    " If you want to save a copy of your results, which by default will be printed\n"
    " on your monitor screen, simply redirect the output to a file, e.g., like\n"
    " \033[1mfitline --sigmas testfiles/radio_7pts > outfile\033[0m\n"
    " Then the command \033[1mcat outfile\033[0m will display the \033[1moutfile\033[0m.\n\n"

    " Trouble or bug reports?  Send an email to Peter Scott <" << PACKAGE_BUGREPORT << ">.\n\n"

    " \t\t-------------------------------------\n";

  prn_usage(argv);
  #endif
}
