// ---
// Results get printed on the screen.  Redirect
// the output to a file if you want to keep it.
//

#include "fitline.h"

void prn_results(result& r, opts& o)
{
  time_t now = time(NULL);
  string s;                         // string for chi-square/deg of freedom
  struct tm* info = localtime(&now);
  const string fmt = "%I:%M %p on %b %d, %Y";

  string    td;
  osstream  oss;
  osstream  oslope;
  osstream  ointercept;

  gstrftime(td, fmt, info);

  cint  fw = (r.ssize && o.sigmas) ? 31 : 26;                // field width
  cstring sig = o.sigmas ? "yes" : "no";        // sigmas option specified?
  r.sigmas = o.sigmas;                         // used for graph errorbars.
  if (o.sigmas && !r.ssize) {
    err("  You've specified the \"--sigmas\" option, but\n",
    "     I don't see any sigmas in your datafile!");
  }

  r.td = td;                                 // store time/date string in r
  cout << "\n  Results at " << td << ":\n\n";      // display time and date

  oss.precision(4);
  oslope.precision(4);
  ointercept.precision(4);
  cout.precision(4);
  oslope     << showpoint << r.a << " +/- " << r.siga;
  ointercept << showpoint << r.b << " +/- " << r.sigb;
  cout
    << left
    << setw(fw) << "  data filename"            << " = " << r.datafile       << "\n"
    << setw(fw) << "  sigmas option specified?" << " = " << sig              << "\n"
    << setw(fw) << "  number of data points"    << " = " << r.npts           << "\n"
    << setw(fw) << "  degrees of freedom"       << " = " << r.npts - 2       << "\n"
    << setw(fw) << "  slope"                    << " = " << oslope.str()     << "\n"
    << setw(fw) << "  intercept"                << " = " << ointercept.str() << "\n"
    << setw(fw) << "  correlation coefficient"  << " = " << r.corr           << "\n"
    << setw(fw) << "  confidence level"         << " = " << r.conf   << " percent\n";
  if (!o.sigmas) {// show phi-min (which is not chisq!)
    cout
    << setw(fw) << "  minimum value of phi"     << " = " << r.chisq          << "\n";
  }

  if (r.ssize && o.sigmas) {// chi-square relevant only for independent sigmas
    oss.str("");
    oss << r.chisq/(r.npts-2);
    s = oss.str();
    cout << setw(fw) << "  chi-square"                    << " = " << r.chisq << "\n"
         << setw(fw) << "  chi-square per deg of freedom" << " = " << s       << "\n"
         << setw(fw) << "  alpha"                         << " = " << r.alpha << "\n"
         << "\n"
            "    alpha is the probability that a larger\n"
            "    value of chi-square would be obtained for an\n"
            "    equivalent data set, assuming the data to be\n"
            "    drawn from a normal distribution.\n"
            "\n";
  }
  else if (r.ssize && !o.sigmas) {       // sigmas present in the datafile,
      cout << "\n"                                // but no --sigmas option
              "   No meaningful values of either chi-square or its\n"
              "   associated probability alpha are available without\n"
              "   independent sigmas.  I'm assuming your sigmas are\n"
              "   relative, and not independently calculated.\n"
              "\n";
  }
  else {                   // sigmas (column 3) not present in the datafile
      cout << "\n"
              "   No meaningful values of either chi-square or its\n"
              "   associated probability alpha are available without\n"
              "   independent sigmas.  Since I see no sigmas in your\n"
              "   datafile, I'm assuming you intend to give equal\n"
              "   weight to each point.\n"
              "\n";
  }
  if (query_user()) {
    cerr << "  OK, here is a graph...\n\n";
    mk_graph(r,o);
  }
  else {
    cerr << "  All right, no graph this time...\n\n";
  }
}

no_yes query_user()                        // just asks the yes/no question
{
  string    answer;
  string    line;
  isstream  iss;

  cerr << "  Would you like to view a graph of your fit? ([yes] or no) ";
  getline(cin, line);
  cout << "\n";
  iss.str(line);
  assert(iss);
  iss >> answer;
  if (!iss || answer[0] == 'y' || answer[0] == 'Y')
    return yes;
  return no;
}
